@@ -1,6 +1,7 @@
 import json
 import logging
 import traceback
+from typing import Union, Any
 
 import sentry_sdk
 from sentry_sdk import capture_exception, configure_scope
@@ -240,6 +241,18 @@ class ListMixin(object):
 
 class BaseHandler(object):
 
+    # type hints
+    user: Any
+    queryset: Any
+    object: Any
+    body: dict
+    messages: list
+    file: dict
+
+    event: dict
+    error: Union[list, tuple]
+    force_error: bool
+
     success_code = 200
 
     def perform_action(self):
@@ -266,6 +279,7 @@ class BaseHandler(object):
             self.body = {}
             self.response_body = {}
             self.messages = {}
+            self.force_error = False
 
             # set user, queryset, object, body and response_body (that is, if the handler
             # uses the apropiate mixin and the method is avaliable)
@@ -284,9 +298,13 @@ class BaseHandler(object):
                     try:
                         setattr(self, attr, getattr(self, method)())
                     except Exception as e:
+                        if self.force_error:
+                            raise
                         if not self.error:
                             tb = traceback.format_exc()
                             return self.render_500_error_response(e, tb)
+                if self.force_error:
+                    raise
                 if self.error:
                     return self.render_error_response(self.error[0], self.error[1])
 
